<?php
/*-----------------------------------------------------*/
/*	StupidBouncy.subs.php
/*-----------------------------------------------------*/

/*	@package Stupid Bouncy BBC
	@Version 2.0

	This modification is licensed under the ISC license.
	https://opensource.org/licenses/ISC

	Copyright (c) 2022, Antechinus

	Permission to use, copy, modify, and/or distribute this software
	for any purpose with or without fee is hereby granted, provided that
	the above copyright notice and this permission notice appear in all copies.

	THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE
	INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE
	LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
	RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
	OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
/*-----------------------------------------------------------------------------------------------------*/

use BBC\Codes;

/**
 * No Bounce, No Parrots
 * @return bool
 */
function isBounceDisabled()
{
	global $modSettings;

	$disabled = !empty($modSettings['disabledBBC']) ? explode(',', $modSettings['disabledBBC']) : [];
	if (in_array('bouncy', $disabled, true))
	{
		return true;
	}

	return false;
}

/**
 * Calls CSS file (if tag is not disabled in admin).
 * @return void
 */
function stupid_css()
{
	if (isBounceDisabled())
	{
		return;
	}

	loadCSSFile('stupid_bouncy.css');
}

/**
 * Calls JS file (if tag is not disabled in admin).
 * @return void
 */
function stupid_js()
{
	if (isBounceDisabled())
	{
		return;
	}

	loadJavascriptFile('stupid_freeze.min.js', array('defer' => true));
}

/**
 * Codes hook for 1.1.x - integrate_additional_bbc
 * Called from ParseWrapper getCodes()
 *
 * @param $codes
 * @return void
 */
function stupid_bounces(&$codes)
{
	// Bouncy with a bird cage load of options
	$codes[] = array(
		Codes::ATTR_TAG => 'bouncy',
		Codes::ATTR_TYPE => Codes::TYPE_PARSED_CONTENT,
		Codes::ATTR_PARAM => array(
			'bounce' => array(
				Codes::PARAM_ATTR_VALUE => ' $1',
				Codes::PARAM_ATTR_MATCH => '([a-z\-]{1,9}|[a-z\-]{1,9}\_[a-z\-]{1,9}|[a-z\-]{1,9}\_[a-z\-]{1,9}\_[a-z\-]{1,9})',
				Codes::PARAM_ATTR_OPTIONAL => true,
			),
			'height' => array(
				Codes::PARAM_ATTR_VALUE => 'height:$1px;',
				Codes::PARAM_ATTR_MATCH => '(\d+)',
				Codes::PARAM_ATTR_OPTIONAL => true,
			),
			'hover' => array(
				Codes::PARAM_ATTR_VALUE => ' $1',
				Codes::PARAM_ATTR_MATCH => '([a-z\-]{1,9})',
				Codes::PARAM_ATTR_OPTIONAL => true,
			),
			'padding' => array(
				Codes::PARAM_ATTR_VALUE => ' style="padding:$1px calc($1px / 2)"',
				Codes::PARAM_ATTR_MATCH => '(\d+)',
				Codes::PARAM_ATTR_OPTIONAL => true,
			),
			'time' => array(
				Codes::PARAM_ATTR_VALUE => 'animation-duration:$1s',
				Codes::PARAM_ATTR_MATCH => '(\d+)',
				Codes::PARAM_ATTR_OPTIONAL => true,
			),
			'toggle' => array(
				Codes::PARAM_ATTR_VALUE => ' parrot_show',
				Codes::PARAM_ATTR_MATCH => '(true)',
				Codes::PARAM_ATTR_OPTIONAL => true,
			),
		),
		Codes::ATTR_BEFORE => '<div class="parrot_kingdom{bounce}{hover}"{padding}><span class="parrot_toggle{toggle}"></span><div class="parrot_cage" style="{height}{time}"><div class="parrot" style="{time}">',
		Codes::ATTR_AFTER => '</div></div></div>',
		Codes::ATTR_DISALLOW_CHILDREN => array('bouncy', 'center', 'code', 'hr', 'left', 'list', 'me', 'quote', 'right', 'spoiler', 'table'),
		Codes::ATTR_BLOCK_LEVEL => false,
		Codes::ATTR_AUTOLINK => true,
		Codes::ATTR_LENGTH => 6,
	);

	// A plain old tag
	$codes[] = array(
		Codes::ATTR_TAG => 'bouncy',
		Codes::ATTR_TYPE => Codes::TYPE_PARSED_CONTENT,
		Codes::ATTR_BEFORE => '<div class="parrot_kingdom"><span class="parrot_toggle"></span><div class="parrot_cage"><div class="parrot">',
		Codes::ATTR_AFTER => '</div></div></div>',
		Codes::ATTR_DISALLOW_CHILDREN => array('bouncy', 'center', 'code', 'hr', 'left', 'list', 'me', 'quote', 'right', 'spoiler', 'table'),
		Codes::ATTR_BLOCK_LEVEL => false,
		Codes::ATTR_AUTOLINK => true,
		Codes::ATTR_LENGTH => 6,
	);
}